==> 4.0.2-DEV1.tar.gz: plan/Plan/src/main/java/com/djrapitops/plan/utilities/uuid/UUIDUtility.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package main.java.com.djrapitops.plan.utilities.uuid;

import com.djrapitops.plugin.utilities.player.UUIDFetcher;
import main.java.com.djrapitops.plan.Log;
import main.java.com.djrapitops.plan.database.Database;
import main.java.com.djrapitops.plan.utilities.MiscUtils;

import java.sql.SQLException;
import java.util.UUID;

/**
 * @author Rsl1122
 */
public class UUIDUtility {

    /**
     * Constructor used to hide the public constructor
     */
    private UUIDUtility() {
        throw new IllegalStateException("Utility class");
    }

    /**
     * Get UUID of a player.
     *
     * @param playerName Player's name
     * @return UUID of the player.
     */
    public static UUID getUUIDOf(String playerName) {
        try {
            return getUUIDOf(playerName, MiscUtils.getIPlan().getDB());
        } catch (Exception e) {
            return null;
        }
    }

    /**
     * Get UUID of a player.
     *
     * @param playerName Player's name
     * @param db         Database to check from.
     * @return UUID of the player
     */
    public static UUID getUUIDOf(String playerName, Database db) {
        UUID uuid = null;
        try {
            uuid = db.getUsersTable().getUuidOf(playerName);
        } catch (SQLException e) {
            Log.toLog("UUIDUtility", e);
        }
        try {
            if (uuid == null) {
                uuid = UUIDFetcher.getUUIDOf(playerName);
            }
        } catch (Exception | NoClassDefFoundError ignored) {
            /* Ignored */
        }
        return uuid;
    }
}

==> 4.0.6-DEV1.tar.gz: plan/Plan/src/main/java/com/djrapitops/plan/utilities/uuid/UUIDUtility.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package main.java.com.djrapitops.plan.utilities.uuid;

import com.djrapitops.plugin.api.utility.UUIDFetcher;
import com.djrapitops.plugin.api.utility.log.Log;
import main.java.com.djrapitops.plan.database.Database;
import main.java.com.djrapitops.plan.utilities.MiscUtils;

import java.sql.SQLException;
import java.util.UUID;

/**
 * @author Rsl1122
 */
public class UUIDUtility {

    /**
     * Constructor used to hide the public constructor
     */
    private UUIDUtility() {
        throw new IllegalStateException("Utility class");
    }

    /**
     * Get UUID of a player.
     *
     * @param playerName Player's name
     * @return UUID of the player.
     */
    public static UUID getUUIDOf(String playerName) {
        try {
            return getUUIDOf(playerName, MiscUtils.getIPlan().getDB());
        } catch (Exception e) {
            return null;
        }
    }

    /**
     * Get UUID of a player.
     *
     * @param playerName Player's name
     * @param db         Database to check from.
     * @return UUID of the player
     */
    public static UUID getUUIDOf(String playerName, Database db) {
        UUID uuid = null;
        try {
            uuid = db.getUsersTable().getUuidOf(playerName);
        } catch (SQLException e) {
            Log.toLog("UUIDUtility", e);
        }
        try {
            if (uuid == null) {
                uuid = UUIDFetcher.getUUIDOf(playerName);
            }
        } catch (Exception | NoClassDefFoundError ignored) {
            /* Ignored */
        }
        return uuid;
    }
}
